/*****************************
 Resends un-ack'd packets
 (c) 1999 Jeremy Wise
 GnomeICU
******************************/

#ifndef __MSG_QUEUE_H__
#define __MSG_QUEUE_H__

#include "datatype.h"

struct msg
{
    int seq;
    int attempts;
    int exp_time;
    BYTE *body;
    int len;
};

struct msg_queue_entry
{
    struct msg *msg;
    struct msg_queue_entry *next;
};

struct msg_queue
{
    int entries;
    struct msg_queue_entry *head;
    struct msg_queue_entry *tail;
};

void msg_queue_init( void );
struct msg *msg_queue_peek( void );
struct msg *msg_queue_pop( void );
void msg_queue_push( struct msg *new_msg );
void Check_Queue( WORD seq );
void msg_queue_clear( void );

#endif /* __MSG_QUEUE_H__ */
